# Table of Contents

- [importing-fact-sheet-data-through-excel-file](<./importing-fact-sheet-data-through-excel-file.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Importing Fact Sheet Data Through Excel File](<./Importing-Fact-Sheet-Data-Through-Excel-File.md>)
  - [Overview](<./Importing-Fact-Sheet-Data-Through-Excel-File/Overview.md>)
  - [Limitations](<./Importing-Fact-Sheet-Data-Through-Excel-File/Limitations.md>)
  - [Step 1: Create an Import Template](<./Importing-Fact-Sheet-Data-Through-Excel-File/Step-1-Create-an-Import-Template.md>)
  - [ReadMe Sheet in Template](<./Importing-Fact-Sheet-Data-Through-Excel-File/ReadMe-Sheet-in-Template.md>)
  - [Step 2: Update the Data in the Spreadsheet](<./Importing-Fact-Sheet-Data-Through-Excel-File/Step-2-Update-the-Data-in-the-Spreadsheet.md>)
  - [Key Concepts and Formatting Rules](<./Importing-Fact-Sheet-Data-Through-Excel-File/Key-Concepts-and-Formatting-Rules.md>)
  - [Overwrite Principle](<./Importing-Fact-Sheet-Data-Through-Excel-File/Overwrite-Principle.md>)
  - [Read-Only Fields](<./Importing-Fact-Sheet-Data-Through-Excel-File/Read-Only-Fields.md>)
  - [General Formatting Rules](<./Importing-Fact-Sheet-Data-Through-Excel-File/General-Formatting-Rules.md>)
  - [Single- and Multi-Select Fields](<./Importing-Fact-Sheet-Data-Through-Excel-File/Single--and-Multi-Select-Fields.md>)
  - [Relations](<./Importing-Fact-Sheet-Data-Through-Excel-File/Relations.md>)
  - [Data Import Sequence and Dependencies](<./Importing-Fact-Sheet-Data-Through-Excel-File/Data-Import-Sequence-and-Dependencies.md>)
  - [Fields on Relation](<./Importing-Fact-Sheet-Data-Through-Excel-File/Fields-on-Relation.md>)
  - [Subscriptions](<./Importing-Fact-Sheet-Data-Through-Excel-File/Subscriptions.md>)
  - [Step 3: Upload the File, Review, and Correct Errors](<./Importing-Fact-Sheet-Data-Through-Excel-File/Step-3-Upload-the-File-Review-and-Correct-Errors.md>)
  - [Troubleshooting](<./Importing-Fact-Sheet-Data-Through-Excel-File/Troubleshooting.md>)
  - [Reviewing Import History](<./Importing-Fact-Sheet-Data-Through-Excel-File/Reviewing-Import-History.md>)
  - [Was this page helpful?](<./Importing-Fact-Sheet-Data-Through-Excel-File/Was-this-page-helpful.md>)
